@@ -2,7 +2,7 @@ import os
 import numpy as np
 import pandas as pd
 import seaborn as sns
-from .ChangePointModel import ChangePointModel
+from ChangePointModel import ChangePointModel
 
 class NMEC:
     """
@@ -56,10 +56,9 @@ class NMEC:
         
         if cp_type.upper() in ["3PH", "3PC"]:
             df = my_model.df
-            train_estimate, coeffs = my_model.train(df.dropna().copy())
+            train_estimate = my_model.train(df.dropna().copy())
 
-            return {"coeffs": coeffs,
-                    "data": train_estimate
+            return {"data": train_estimate
                     # 'metrics': my_model.metrics(train_estimate)
                     }
 
@@ -72,15 +71,14 @@ class NMEC:
                 df_occ = my_model.df
                 df_unocc = None
                 
-            train_estimate, coeffs = my_model.train(df_occ.dropna().copy())
-            print(coeffs)
+            train_estimate= my_model.train(df_occ.dropna().copy())
+            
             if df_unocc is not None:
                 train_estimate = my_model.train(
                     df_unocc.dropna().copy(), train_estimate)
 
             if train_estimate is not None:
                 return {
-                        "coeffs": coeffs,
                         "data": train_estimate
                         # 'metrics': my_model.metrics(train_estimate)
                         }
@@ -89,7 +87,7 @@ class NMEC:
                     'No Training Estimate, check if Type is SLR, 2P, 3PH, or 3PC')
   
 
-    def example(self, model_type="SLR"):
+    def example(self, model_type="3PH"):
         print("modeling with type", model_type)
 
         df = pd.read_csv(
